@@ -2,7 +2,7 @@
 
 package WebService::OpenSky::Response;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 use Moose;
 use WebService::OpenSky::Utils::Iterator;
 use WebService::OpenSky::Types qw(
@@ -112,7 +112,7 @@ WebService::OpenSky::Response - A class representing a response from the OpenSky
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 DESCRIPTION
 
@@ -135,7 +135,11 @@ The query used to retrieve this response.
 
 =head2 iterator
 
-Returns an iterator of L<WebService::OpenSky::Core::Flight> objects.
+Returns an iterator of results. See L<WebService::OpenSky> to understand the
+actual response class returned for a given method and which underlying module
+represents the results. (Typically this would be
+L<WebService::OpenSky::Core::Flight> or
+L<WebService::OpenSky::Core::StateVector>.)
 
 As a convenience, the following methods are delegated to the iterator:
 
