@@ -2,7 +2,7 @@
 
 package WebService::OpenSky::Response::Flights;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 use Moose;
 use WebService::OpenSky::Core::Flight;
 use experimental qw(signatures);
@@ -30,13 +30,13 @@ WebService::OpenSky::Response::Flights - A class representing a flights response
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 DESCRIPTION
 
 This class inherits from L<WebService::OpenSky::Response>. Please see that
 module for the available methods. Individual responses are from the
-L<WesbService::OpenSky::Core::Flight> class.
+L<WebService::OpenSky::Core::Flight> class.
 
 =head1 AUTHOR
 
