@@ -2,7 +2,7 @@
 
 package WebService::OpenSky::Response::States;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 use Moose;
 use WebService::OpenSky::Core::StateVector;
 use experimental qw(signatures);
@@ -32,13 +32,13 @@ WebService::OpenSky::Response::States - A class representing a states response f
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 DESCRIPTION
 
 This class inherits from L<WebService::OpenSky::Response>. Please see that
 module for the available methods. Individual responses are from the
-L<WesbService::OpenSky::Core::StateVector> class.
+L<WebService::OpenSky::Core::StateVector> class.
 
 =head1 AUTHOR
 
